![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/tandav/dagops)

# dagops
dag/task runner


## install
### install from [pypi](https://pypi.org/project/dagops/)
```sh
pip install dagops
```

### or install the latest version from github
```sh
pip install git+https://github.com/tandav/dagops
```

### development
```sh
pip install -e .[dev]
```
